==> aTunes_1.9.0.tar.gz: aTunes/src/net/sourceforge/atunes/gui/substance/SubstanceATunesGraySkin.java <==
/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.substance;

import java.awt.Color;

import org.jvnet.substance.border.GlassBorderPainter;
import org.jvnet.substance.button.ClassicButtonShaper;
import org.jvnet.substance.color.BaseColorScheme;
import org.jvnet.substance.painter.AlphaControlBackgroundComposite;
import org.jvnet.substance.painter.GlassGradientPainter;
import org.jvnet.substance.painter.SimplisticSoftBorderReverseGradientPainter;
import org.jvnet.substance.painter.decoration.DecorationAreaType;
import org.jvnet.substance.painter.decoration.MatteDecorationPainter;
import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
import org.jvnet.substance.skin.SubstanceAbstractSkin;
import org.jvnet.substance.theme.SubstanceComplexTheme;
import org.jvnet.substance.theme.SubstanceTheme;
import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
import org.jvnet.substance.watermark.SubstanceNullWatermark;

/**
 * The Class SubstanceATunesSkin.
 */
public class SubstanceATunesGraySkin extends SubstanceAbstractSkin {

	/** Display name for <code>this</code> skin. */
	private static final String NAME = "aTunes Gray";

	static class GrayColorScheme extends BaseColorScheme {

		private Color ultraDarkColor = new Color(65, 65, 70);
		private Color darkColor = new Color(95, 95, 100);
		private Color midColor = new Color(150, 150, 155);
		private Color lightColor = new Color(170, 170, 175);
		private Color extraLightColor = new Color(180, 180, 185);
		private Color ultraLightColor = new Color(190, 190, 195);
		private Color foregroundColor = new Color(55, 55, 55);

		@Override
		public Color getUltraDarkColor() {
			return ultraDarkColor;
		}

		@Override
		public Color getDarkColor() {
			return darkColor;
		}

		@Override
		public Color getMidColor() {
			return midColor;
		}

		@Override
		public Color getLightColor() {
			return lightColor;
		}

		@Override
		public Color getExtraLightColor() {
			return extraLightColor;
		}

		@Override
		public Color getUltraLightColor() {
			return ultraLightColor;
		}

		@Override
		public Color getForegroundColor() {
			return foregroundColor;
		}

	}

	static class MetallicColorScheme extends BaseColorScheme {
		private Color ultraDarkColor = new Color(105, 105, 110);
		private Color darkColor = new Color(125, 125, 130); // Controls' border
		private Color midColor = new Color(145, 145, 155); // Used for buttons, table headers and scroll bars
		private Color lightColor = new Color(165, 165, 175); // Background
		private Color extraLightColor = new Color(195, 195, 200); // Background
		private Color ultraLightColor = new Color(215, 215, 220); // Used for buttons, table headers and scroll bars
		private Color foregroundColor = new Color(50, 50, 50);

		@Override
		public Color getUltraDarkColor() {
			return ultraDarkColor;
		}

		@Override
		public Color getDarkColor() {
			return darkColor;
		}

		@Override
		public Color getMidColor() {
			return midColor;
		}

		@Override
		public Color getLightColor() {
			return lightColor;
		}

		@Override
		public Color getExtraLightColor() {
			return extraLightColor;
		}

		@Override
		public Color getUltraLightColor() {
			return ultraLightColor;
		}

		@Override
		public Color getForegroundColor() {
			return foregroundColor;
		}
	}

	/**
	 * Creates a new skin.
	 */
	@SuppressWarnings("deprecation")
	public SubstanceATunesGraySkin() {

		SubstanceTheme activeTheme = new SubstanceTheme(new GrayColorScheme(), "aTunes Gray", ThemeKind.COLD);
		SubstanceTheme defaultTheme = new SubstanceTheme(new MetallicColorScheme(), "Metallic", ThemeKind.COLD);
		SubstanceTheme disabledTheme = defaultTheme.tint(0.3);
		SubstanceTheme activeTitleTheme = activeTheme;

		SubstanceComplexTheme complexTheme = new SubstanceComplexTheme(NAME, ThemeKind.DARK, activeTheme, defaultTheme, disabledTheme, activeTitleTheme);
		complexTheme.registerDecorationAreaTheme(activeTitleTheme, false, DecorationAreaType.PRIMARY_TITLE_PANE, DecorationAreaType.SECONDARY_TITLE_PANE,
				DecorationAreaType.HEADER, DecorationAreaType.TOOLBAR);

		complexTheme.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());

		this.theme = complexTheme;
		this.buttonShaper = new ClassicButtonShaper();
		this.watermark = new SubstanceNullWatermark();
		this.gradientPainter = new GlassGradientPainter();
		this.decorationPainter = new MatteDecorationPainter();
		this.highlightPainter = new ClassicHighlightPainter();
		tabBackgroundComposite = new AlphaControlBackgroundComposite(0.5f);
		this.borderPainter = new GlassBorderPainter();

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jvnet.substance.skin.SubstanceSkin#getDisplayName()
	 */
	@Override
	public String getDisplayName() {
		return "aTunes Gray skin";
	}

}

==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/gui/substance/SubstanceATunesGraySkin.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.substance;

import java.awt.Color;

import org.jvnet.substance.api.SubstanceColorScheme;
import org.jvnet.substance.api.SubstanceColorSchemeBundle;
import org.jvnet.substance.api.SubstanceSkin;
import org.jvnet.substance.colorscheme.BaseDarkColorScheme;
import org.jvnet.substance.colorscheme.TintColorScheme;
import org.jvnet.substance.painter.border.GlassBorderPainter;
import org.jvnet.substance.painter.decoration.DecorationAreaType;
import org.jvnet.substance.painter.decoration.MatteDecorationPainter;
import org.jvnet.substance.painter.gradient.GlassGradientPainter;
import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
import org.jvnet.substance.shaper.ClassicButtonShaper;
import org.jvnet.substance.watermark.SubstanceNullWatermark;

/**
 * The Class SubstanceATunesSkin.
 */
public class SubstanceATunesGraySkin extends SubstanceSkin {

	static class GrayColorScheme extends BaseDarkColorScheme {

		public GrayColorScheme(String displayName) {
			super(displayName);
		}

		private Color ultraDarkColor = new Color(65, 65, 70);
		private Color darkColor = new Color(95, 95, 100);
		private Color midColor = new Color(150, 150, 155);
		private Color lightColor = new Color(170, 170, 175);
		private Color extraLightColor = new Color(180, 180, 185);
		private Color ultraLightColor = new Color(190, 190, 195);
		private Color foregroundColor = new Color(55, 55, 55);

		@Override
		public Color getUltraDarkColor() {
			return ultraDarkColor;
		}

		@Override
		public Color getDarkColor() {
			return darkColor;
		}

		@Override
		public Color getMidColor() {
			return midColor;
		}

		@Override
		public Color getLightColor() {
			return lightColor;
		}

		@Override
		public Color getExtraLightColor() {
			return extraLightColor;
		}

		@Override
		public Color getUltraLightColor() {
			return ultraLightColor;
		}

		@Override
		public Color getForegroundColor() {
			return foregroundColor;
		}

	}

	static class MetallicColorScheme extends BaseDarkColorScheme {

		protected MetallicColorScheme(String displayName) {
			super(displayName);
		}

		private Color ultraDarkColor = new Color(105, 105, 110);
		private Color darkColor = new Color(125, 125, 130); // Controls' border
		private Color midColor = new Color(145, 145, 155); // Used for buttons, table headers and scroll bars
		private Color lightColor = new Color(165, 165, 175); // Background
		private Color extraLightColor = new Color(195, 195, 200); // Background
		private Color ultraLightColor = new Color(215, 215, 220); // Used for buttons, table headers and scroll bars
		private Color foregroundColor = new Color(50, 50, 50);

		@Override
		public Color getUltraDarkColor() {
			return ultraDarkColor;
		}

		@Override
		public Color getDarkColor() {
			return darkColor;
		}

		@Override
		public Color getMidColor() {
			return midColor;
		}

		@Override
		public Color getLightColor() {
			return lightColor;
		}

		@Override
		public Color getExtraLightColor() {
			return extraLightColor;
		}

		@Override
		public Color getUltraLightColor() {
			return ultraLightColor;
		}

		@Override
		public Color getForegroundColor() {
			return foregroundColor;
		}
	}

	/**
	 * Creates a new skin.
	 */
	public SubstanceATunesGraySkin() {

		SubstanceColorScheme activeScheme = new GrayColorScheme("aTunes Gray");
		SubstanceColorScheme defaultScheme = new MetallicColorScheme("Metallic");
		SubstanceColorScheme disabledScheme = new TintColorScheme(defaultScheme, 0.3);

		// the default theme bundle
		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(activeScheme, defaultScheme, disabledScheme);
		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle, DecorationAreaType.NONE);

		// the special theme bundle
		SubstanceColorSchemeBundle specialSchemeBundle = new SubstanceColorSchemeBundle(activeScheme, activeScheme, disabledScheme);
		this.registerDecorationAreaSchemeBundle(specialSchemeBundle, DecorationAreaType.PRIMARY_TITLE_PANE, DecorationAreaType.SECONDARY_TITLE_PANE, DecorationAreaType.TOOLBAR,
				DecorationAreaType.FOOTER, DecorationAreaType.HEADER, DecorationAreaType.GENERAL);

		this.buttonShaper = new ClassicButtonShaper();
		this.watermark = new SubstanceNullWatermark();
		this.gradientPainter = new GlassGradientPainter();
		this.decorationPainter = new MatteDecorationPainter();
		this.highlightPainter = new ClassicHighlightPainter();
		this.borderPainter = new GlassBorderPainter();

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jvnet.substance.skin.SubstanceSkin#getDisplayName()
	 */
	@Override
	public String getDisplayName() {
		return "aTunes Gray skin";
	}

}
